==> jc-1.4.0.tar.gz: javax/swing/event/ListSelectionEvent.h <==
// public class javax.swing.event.ListSelectionEvent

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class 5e01f39001c0f9e4 javax_swing_event_ListSelectionEvent

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_javax_swing_event_ListSelectionEvent_H_
#define _JC_javax_swing_event_ListSelectionEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_event_ListSelectionEvent$sub_refs	_jc_javax_swing_event_ListSelectionEvent$sub_refs;
typedef struct _jc_javax_swing_event_ListSelectionEvent$sub_nonrefs	_jc_javax_swing_event_ListSelectionEvent$sub_nonrefs;
typedef struct _jc_javax_swing_event_ListSelectionEvent$refs	_jc_javax_swing_event_ListSelectionEvent$refs;
typedef struct _jc_javax_swing_event_ListSelectionEvent$nonrefs	_jc_javax_swing_event_ListSelectionEvent$nonrefs;
typedef struct _jc_javax_swing_event_ListSelectionEvent$object	_jc_javax_swing_event_ListSelectionEvent$object;

typedef const struct _jc_javax_swing_event_ListSelectionEvent$vmethods	_jc_javax_swing_event_ListSelectionEvent$vmethods;
typedef const struct _jc_javax_swing_event_ListSelectionEvent$vtable	_jc_javax_swing_event_ListSelectionEvent$vtable;
typedef const struct _jc_javax_swing_event_ListSelectionEvent$vtype	_jc_javax_swing_event_ListSelectionEvent$vtype;

// Constructors
extern void _jc_javax_swing_event_ListSelectionEvent$method$_init$01c1637c3769169f(_jc_env *, struct _jc_javax_swing_event_ListSelectionEvent$object *, struct _jc_java_lang_Object$object *, jint, jint, jboolean);

// Virtual methods
extern jint _jc_javax_swing_event_ListSelectionEvent$method$getFirstIndex$a2051197609eaba1(_jc_env *, struct _jc_javax_swing_event_ListSelectionEvent$object *);
extern jint _jc_javax_swing_event_ListSelectionEvent$method$getLastIndex$8746d7c65ac30dec(_jc_env *, struct _jc_javax_swing_event_ListSelectionEvent$object *);
extern jboolean _jc_javax_swing_event_ListSelectionEvent$method$getValueIsAdjusting$927e01af49261dcb(_jc_env *, struct _jc_javax_swing_event_ListSelectionEvent$object *);
extern void _jc_javax_swing_event_ListSelectionEvent$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_swing_event_ListSelectionEvent$object *);
extern struct _jc_java_lang_String$object *_jc_javax_swing_event_ListSelectionEvent$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_swing_event_ListSelectionEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_event_ListSelectionEvent$method_info$getFirstIndex$a2051197609eaba1;
extern _jc_method _jc_javax_swing_event_ListSelectionEvent$method_info$getLastIndex$8746d7c65ac30dec;
extern _jc_method _jc_javax_swing_event_ListSelectionEvent$method_info$getValueIsAdjusting$927e01af49261dcb;
extern _jc_method _jc_javax_swing_event_ListSelectionEvent$method_info$this$adc93fb6bf4cbffa;
extern _jc_method _jc_javax_swing_event_ListSelectionEvent$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_javax_swing_event_ListSelectionEvent$vmethods {
	jint	(*getFirstIndex$a2051197609eaba1)(_jc_env *, struct _jc_javax_swing_event_ListSelectionEvent$object *);
	jint	(*getLastIndex$8746d7c65ac30dec)(_jc_env *, struct _jc_javax_swing_event_ListSelectionEvent$object *);
	jboolean	(*getValueIsAdjusting$927e01af49261dcb)(_jc_env *, struct _jc_javax_swing_event_ListSelectionEvent$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_swing_event_ListSelectionEvent$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_swing_event_ListSelectionEvent$object *);
};

// Vtable
struct _jc_javax_swing_event_ListSelectionEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_javax_swing_event_ListSelectionEvent$vmethods	javax_swing_event_ListSelectionEvent;
};

// Vtype
struct _jc_javax_swing_event_ListSelectionEvent$vtype {
	_jc_type			type;
	_jc_javax_swing_event_ListSelectionEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_event_ListSelectionEvent$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_event_ListSelectionEvent$refs {
    _jc_javax_swing_event_ListSelectionEvent$sub_refs	javax_swing_event_ListSelectionEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_event_ListSelectionEvent$sub_nonrefs {
	jint	firstIndex;
	jint	lastIndex;
	jboolean	isAdjusting;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_event_ListSelectionEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_javax_swing_event_ListSelectionEvent$sub_nonrefs	javax_swing_event_ListSelectionEvent;
};

// Object instance structure
struct _jc_javax_swing_event_ListSelectionEvent$object {
	_jc_javax_swing_event_ListSelectionEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_event_ListSelectionEvent$vtype	*vtype;
	_jc_javax_swing_event_ListSelectionEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_event_ListSelectionEvent$vtype _jc_javax_swing_event_ListSelectionEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_event_ListSelectionEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_event_ListSelectionEvent$class_object;

#endif	/* _JC_javax_swing_event_ListSelectionEvent_H_ */

==> jc-1.4.6.tar.gz: javax/swing/event/ListSelectionEvent.h <==
// public class javax.swing.event.ListSelectionEvent

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class 5e01f39001c0f9e4 javax_swing_event_ListSelectionEvent

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_javax_swing_event_ListSelectionEvent_H_
#define _JC_javax_swing_event_ListSelectionEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_event_ListSelectionEvent$sub_refs	_jc_javax_swing_event_ListSelectionEvent$sub_refs;
typedef struct _jc_javax_swing_event_ListSelectionEvent$sub_nonrefs	_jc_javax_swing_event_ListSelectionEvent$sub_nonrefs;
typedef struct _jc_javax_swing_event_ListSelectionEvent$refs	_jc_javax_swing_event_ListSelectionEvent$refs;
typedef struct _jc_javax_swing_event_ListSelectionEvent$nonrefs	_jc_javax_swing_event_ListSelectionEvent$nonrefs;
typedef struct _jc_javax_swing_event_ListSelectionEvent$object	_jc_javax_swing_event_ListSelectionEvent$object;

typedef const struct _jc_javax_swing_event_ListSelectionEvent$vmethods	_jc_javax_swing_event_ListSelectionEvent$vmethods;
typedef const struct _jc_javax_swing_event_ListSelectionEvent$vtable	_jc_javax_swing_event_ListSelectionEvent$vtable;
typedef const struct _jc_javax_swing_event_ListSelectionEvent$vtype	_jc_javax_swing_event_ListSelectionEvent$vtype;

// Constructors
extern void _jc_javax_swing_event_ListSelectionEvent$method$_init$01c1637c3769169f(_jc_env *, struct _jc_javax_swing_event_ListSelectionEvent$object *, struct _jc_java_lang_Object$object *, jint, jint, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_javax_swing_event_ListSelectionEvent$method$getFirstIndex$a2051197609eaba1(_jc_env *, struct _jc_javax_swing_event_ListSelectionEvent$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_event_ListSelectionEvent$method$getLastIndex$8746d7c65ac30dec(_jc_env *, struct _jc_javax_swing_event_ListSelectionEvent$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_swing_event_ListSelectionEvent$method$getValueIsAdjusting$927e01af49261dcb(_jc_env *, struct _jc_javax_swing_event_ListSelectionEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_event_ListSelectionEvent$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_swing_event_ListSelectionEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_swing_event_ListSelectionEvent$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_swing_event_ListSelectionEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_event_ListSelectionEvent$method_info$getFirstIndex$a2051197609eaba1;
extern _jc_method _jc_javax_swing_event_ListSelectionEvent$method_info$getLastIndex$8746d7c65ac30dec;
extern _jc_method _jc_javax_swing_event_ListSelectionEvent$method_info$getValueIsAdjusting$927e01af49261dcb;
extern _jc_method _jc_javax_swing_event_ListSelectionEvent$method_info$this$adc93fb6bf4cbffa;
extern _jc_method _jc_javax_swing_event_ListSelectionEvent$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_javax_swing_event_ListSelectionEvent$vmethods {
	jint	(*getFirstIndex$a2051197609eaba1)(_jc_env *, struct _jc_javax_swing_event_ListSelectionEvent$object *) _JC_JCNI_ATTR;
	jint	(*getLastIndex$8746d7c65ac30dec)(_jc_env *, struct _jc_javax_swing_event_ListSelectionEvent$object *) _JC_JCNI_ATTR;
	jboolean	(*getValueIsAdjusting$927e01af49261dcb)(_jc_env *, struct _jc_javax_swing_event_ListSelectionEvent$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_swing_event_ListSelectionEvent$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_swing_event_ListSelectionEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_event_ListSelectionEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_javax_swing_event_ListSelectionEvent$vmethods	javax_swing_event_ListSelectionEvent;
};

// Vtype
struct _jc_javax_swing_event_ListSelectionEvent$vtype {
	_jc_type			type;
	_jc_javax_swing_event_ListSelectionEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_event_ListSelectionEvent$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_event_ListSelectionEvent$refs {
    _jc_javax_swing_event_ListSelectionEvent$sub_refs	javax_swing_event_ListSelectionEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_event_ListSelectionEvent$sub_nonrefs {
	jint	firstIndex;
	jint	lastIndex;
	jboolean	isAdjusting;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_event_ListSelectionEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_javax_swing_event_ListSelectionEvent$sub_nonrefs	javax_swing_event_ListSelectionEvent;
};

// Object instance structure
struct _jc_javax_swing_event_ListSelectionEvent$object {
	_jc_javax_swing_event_ListSelectionEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_event_ListSelectionEvent$vtype	*vtype;
	_jc_javax_swing_event_ListSelectionEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_event_ListSelectionEvent$vtype _jc_javax_swing_event_ListSelectionEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_event_ListSelectionEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_event_ListSelectionEvent$class_object;

#endif	/* _JC_javax_swing_event_ListSelectionEvent_H_ */
